
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>
#include <gst/app/app-prelude.h>

G_BEGIN_DECLS

/* enumerations from "gstappsrc.h" */

GST_APP_API
GType gst_app_stream_type_get_type (void);
#define GST_TYPE_APP_STREAM_TYPE (gst_app_stream_type_get_type())

GST_APP_API
GType gst_app_leaky_type_get_type (void);
#define GST_TYPE_APP_LEAKY_TYPE (gst_app_leaky_type_get_type())

G_END_DECLS

/* Generated data ends here */

